###############################################################################
#	Filename:	QuantumTorpedo.py
#	
#	Star Trek Bridge Commander: Remastered.
#	
#	Script for filling in the attributes of quantum torpedoes.
#	
#	Created:	17/11/07 -	Glenn Elgy
###############################################################################

import App

###############################################################################
#	Create(pTorp)
#	
#	Creates a quantum torpedo.
#	
#	Args:	pTorp - the torpedo, ready to be filled-in
#	
#	Return:	zero
###############################################################################
def Create(pTorp):
	kCoreColor = App.TGColorA()
	kCoreColor.SetRGBA(255.0 / 255.0,255.0 / 255.0,255.0 / 255.0, 1.000000)
	kGlowColor = App.TGColorA()
	kGlowColor.SetRGBA(23.0 / 255.0,47.0 / 255.0,202.0 / 255.0, 1.000000)	
        kFlareColor = App.TGColorA()
        kFlareColor.SetRGBA(50.0 / 255.0, 50.0 / 255.0, 100.0 / 255.0, 1.0)

	pTorp.CreateTorpedoModel(
					"data/Textures/Tactical/CEPhotonCore.tga",
					kCoreColor, 
					0.2,
					0.6,	 
					"data/Textures/Tactical/CEPhotonGlow.tga", 
					kGlowColor,
					2.0,	
					0.7,	 
					0.85,	
					"data/Textures/Tactical/CETorpedoFlare.tga",
					kGlowColor,									
					18,		
					0.4,		
					0.15)

	pTorp.SetDamage( GetDamage() )
	pTorp.SetDamageRadiusFactor(0.30)
	pTorp.SetGuidanceLifetime( GetGuidanceLifetime() )
	pTorp.SetMaxAngularAccel( GetMaxAngularAccel() )

	# Multiplayer specific stuff.  Please, if you create a new torp
	# type. modify the SpeciesToTorp.py file to add the new type.
	import Multiplayer.SpeciesToTorp
	pTorp.SetNetType (Multiplayer.SpeciesToTorp.QUANTUM)

	return(0)

def GetLaunchSpeed():
	return(35.0)

def GetLaunchSound():
	return("Fed Quantum")

def GetPowerCost():
	return(20.0)

def GetName():
	return("Quantum")

def GetDamage():
	return 1000.0

def GetGuidanceLifetime():
	return 25.0

def GetLifetime():
	return 30.0

def GetMaxAngularAccel():
	return 0.25
